diff src/protocols/msn/error.h @ 5436:ad445074d239

[gaim-migrate @ 5818] Another big commit. Ugh. I need a very smart regexp. Core/UI split do_error_dialog(), and soon the mail dialogs! Yay! This should work without problems at all, but standard disclaimer.. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Sun, 18 May 2003 19:59:02 +0000
parents e2e53316a21d
children b7e113a59b51
line wrap: on
line diff
--- a/src/protocols/msn/error.h	Sun May 18 19:13:21 2003 +0000
+++ b/src/protocols/msn/error.h	Sun May 18 19:59:02 2003 +0000
@@ -22,6 +22,8 @@
 #ifndef _MSN_ERROR_H_
 #define _MSN_ERROR_H_
 
+#include "session.h"
+
 /**
  * Returns the string representation of an error type.
  *
@@ -34,8 +36,9 @@
 /**
  * Handles an error.
  *
  * @param type The error type.
  */
-void msn_error_handle(unsigned int type);
+void msn_error_handle(MsnSession *session, unsigned int type);
 
 #endif /* _MSN_ERROR_H_ */
@@ -34,8 +36,9 @@
  * Handles an error.
  *
- * @param type The error type.
+ * @param session The current session.
+ * @param type    The error type.
  */